```
                      _  _         _    
                     | |(_)       | |   
  __ _  _   _  _ __  | | _  _ __  | | __
 / _` || | | || '_ \ | || || '_ \ | |/ /
| (_| || |_| || | | || || || | | ||   < 
 \__, | \__,_||_| |_||_||_||_| |_||_|\_\
  __/ |                                 
 |___/                                  
```

<p align="center">
  <img width="auto" height="auto" src="https://raw.githubusercontent.com/Brijeshkrishna/gunlink/1d4aa24ec2568a3b18c3bc6c9dd5b26ab76aacf8/gunlink.png">
</p>



![Version](https://img.shields.io/badge/version-1.0.0-blue) ![Python-Version](https://img.shields.io/badge/python-3.9-blue) ![issues](https://img.shields.io/github/issues/Brijeshkrishna/gunlink)  ![License](https://img.shields.io/github/license/brijeshkrishna/gunlink) 

#### A package that allows to handle URL
  
##  Installation
Requests is available on PyPI <img align="center" alt="python" width="40px" src="https://raw.githubusercontent.com/github/explore/80688e429a7d4ef2fca1e82350fe8e3517d3494d/topics/python/python.png" />:

```bash
$ python setup.py install 
```


or
```bash
$ python -m pip install gunlink
```

			
or ,simply 

```bash
$ pip install gunlink
```

Gunlink officially supports Python 2.7 & 3.6+.

## Cloning the repository

``
git clone https://github.com/Brijeshkrishna/gunlink.git
``  

## How to use:

```python
>>> from gunlink import link
>>> gun = link('https://github.com/Brijeshkrishna')
>>> gun.is_valid_link
True
```
 
	
## License

Gunshot is licensed and distributed under the MIT license.  [Contact me](mailto:brijeshkrishnaga@gmail.com)  if you're looking for an exception to the terms. 

## Contributors 
####  If want to Contributor to gunshot contact me .





